@@ -74,7 +74,7 @@ void read_cmap_table(char *file, FontDirectory *fontDirectory,
     for (i = 0; i < n; i++) {
         tableDirectoryEntry = &fontDirectory->tableDirectory[i];
 
-        if (strncmp(tableDirectoryEntry->tag, CMAP_TAG, 4) == 0) {
+        if (strncmp((const char *)tableDirectoryEntry->tag, CMAP_TAG, 4) == 0) {
             break;
         }
     }
@@ -170,7 +170,6 @@ void read_cmap_table(char *file, FontDirectory *fontDirectory,
             else if ((cmapTable->cmapArray[i].cmapEncodingSubtable.platformID == 3)
              && (cmapTable->cmapArray[i].cmapEncodingSubtable.platformSpecificID == 4)) {
                 U2C *u2c;
-                char answer[8];
 
                 u2c = u2c_open(BIG5);
                 
@@ -431,6 +430,7 @@ void add_unicode_cmap(CMapTable *cmapTable,
 
     hasUnicodeCMap = 0;
     u2c = NULL;
+    language = 0;
 
     n = cmapTable->cmapIndex.numberSubtables;
 
